==> verum-dezyne-2.16.0-x86_64-windows.zip: dezyne-2.16.0/gnu/share/guile/site/3.0/dzn/config.scm <==
;;; Dezyne --- Dezyne command line tools
;;;
;;; Copyright © 2017, 2018, 2019, 2020, 2021, 2022 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
;;; Copyright © 2018 Rutger van Beusekom <rutger@dezyne.org>
;;;
;;; This file is part of Dezyne.
;;;
;;; Dezyne is free software: you can redistribute it and/or modify it
;;; under the terms of the GNU Affero General Public License as
;;; published by the Free Software Foundation, either version 3 of the
;;; License, or (at your option) any later version.
;;;
;;; Dezyne is distributed in the hope that it will be useful, but
;;; WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
;;; Affero General Public License for more details.
;;;
;;; You should have received a copy of the GNU Affero General Public
;;; License along with Dezyne.  If not, see <http://www.gnu.org/licenses/>.
;;;
;;; Commentary:
;;;
;;; Compile-time configuration of dzn.  When adding a substitution
;;; variable here, make sure to have configure substitute it.
;;;
;;; Code:

(define-module (dzn config)
  #:use-module (dzn shell-util)
  #:export (%bindir
            %copyright-info
            %datadir
            %datarootdir
            %dzn
            %feature-alist
            %guilemoduledir
            %guileobjectdir
            %default-languages
            %license-info
            %package
            %package-name
            %package-version
            %prefix
            %template-dir
            %test-dir
            %version-major
            %version-minor
            %version-patch))

(define %package
  (or (and (getenv "DZN_UNINSTALLED") "dezyne")
      "dezyne"))

(define %prefix
  (or (and (getenv "DZN_UNINSTALLED") (getenv "DZN_PREFIX"))
      "/gnu/store/lhfiw471jwad9yjgmkqc2b7v6mq48zva-dezyne-mingw-2.16.0"))

(define %datadir
  (or (and (getenv "DZN_UNINSTALLED") %prefix)
      "/gnu/store/lhfiw471jwad9yjgmkqc2b7v6mq48zva-dezyne-mingw-2.16.0/share"))

(define %datarootdir
  (or (and (getenv "DZN_UNINSTALLED") %prefix)
      "/gnu/store/lhfiw471jwad9yjgmkqc2b7v6mq48zva-dezyne-mingw-2.16.0/share"))

(define %pkgdatadir
  (or (and (getenv "DZN_UNINSTALLED") %prefix)
      (getenv "DZN_DATADIR")
      (string-append %datadir "/" %package)))

(define %bindir
  (or (and (getenv "DZN_UNINSTALLED") (string-append %prefix "/bin"))
      "/gnu/store/lhfiw471jwad9yjgmkqc2b7v6mq48zva-dezyne-mingw-2.16.0/bin"))

(define %template-dir
  (string-append %pkgdatadir "/dzn/templates"))

(define %test-dir
  (string-append %pkgdatadir "/test"))

(define %guilemoduledir
  "/gnu/store/lhfiw471jwad9yjgmkqc2b7v6mq48zva-dezyne-mingw-2.16.0/share/guile/site/3.0")

(define %guileobjectdir
  "/gnu/store/lhfiw471jwad9yjgmkqc2b7v6mq48zva-dezyne-mingw-2.16.0/lib/guile/3.0/site-ccache")

(define %package-name
  "Dezyne")

(define %package-version
  "2.16.0")

(define %version-major
  2)

(define %version-minor
  16)

(define %version-patch
  0)

(define %dzn
  (if (mingw?) "dzn.cmd"
      (string-append %bindir "/dzn")))

(define %default-languages
  (string-split (string-trim-both "c++") #\space))

(define %copyright-info
  "Copyright (C) 2014-2022 the Dezyne authors
")

(define %license-info
  "License AGPLv3+: GNU AGPL version 3 or later <https://gnu.org/licenses/agpl.html>
This is free software: you are free to change and redistribute it.
There is NO WARRANTY, to the extent permitted by law.
")

(define %feature-alist
  '(("async" . ("c++" "cs" "scheme"))
    ("block" . ("c++" "cs" "scheme"))
    ("calling_context" . ("c++" "cs" "scheme"))
    ("collateral" . ("c++" "cs" "scheme"))
    ("defer" . ("c++" "cs" "scheme"))
    ("flush" . ("c++" "cs" "scheme"))
    ("inject" . ("c++" "cs" "javacsript" "scheme"))
    ("space" . ("c" "c++" "cs" "javascript" "scheme"))))

==> verum-dezyne-2.16.2-x86_64-windows.zip: dezyne-2.16.2/gnu/share/guile/site/3.0/dzn/config.scm <==
;;; Dezyne --- Dezyne command line tools
;;;
;;; Copyright © 2017, 2018, 2019, 2020, 2021, 2022 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
;;; Copyright © 2018 Rutger van Beusekom <rutger@dezyne.org>
;;;
;;; This file is part of Dezyne.
;;;
;;; Dezyne is free software: you can redistribute it and/or modify it
;;; under the terms of the GNU Affero General Public License as
;;; published by the Free Software Foundation, either version 3 of the
;;; License, or (at your option) any later version.
;;;
;;; Dezyne is distributed in the hope that it will be useful, but
;;; WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
;;; Affero General Public License for more details.
;;;
;;; You should have received a copy of the GNU Affero General Public
;;; License along with Dezyne.  If not, see <http://www.gnu.org/licenses/>.
;;;
;;; Commentary:
;;;
;;; Compile-time configuration of dzn.  When adding a substitution
;;; variable here, make sure to have configure substitute it.
;;;
;;; Code:

(define-module (dzn config)
  #:use-module (dzn shell-util)
  #:export (%bindir
            %copyright-info
            %datadir
            %datarootdir
            %dzn
            %feature-alist
            %guilemoduledir
            %guileobjectdir
            %default-languages
            %license-info
            %package
            %package-name
            %package-version
            %prefix
            %template-dir
            %test-dir
            %version-major
            %version-minor
            %version-patch))

(define %package
  (or (and (getenv "DZN_UNINSTALLED") "dezyne")
      "dezyne"))

(define %prefix
  (or (and (getenv "DZN_UNINSTALLED") (getenv "DZN_PREFIX"))
      "/gnu/store/fabyp52qj67piyzm3qbsndys6h3jf525-dezyne-mingw-2.16.2"))

(define %datadir
  (or (and (getenv "DZN_UNINSTALLED") %prefix)
      "/gnu/store/fabyp52qj67piyzm3qbsndys6h3jf525-dezyne-mingw-2.16.2/share"))

(define %datarootdir
  (or (and (getenv "DZN_UNINSTALLED") %prefix)
      "/gnu/store/fabyp52qj67piyzm3qbsndys6h3jf525-dezyne-mingw-2.16.2/share"))

(define %pkgdatadir
  (or (and (getenv "DZN_UNINSTALLED") %prefix)
      (getenv "DZN_DATADIR")
      (string-append %datadir "/" %package)))

(define %bindir
  (or (and (getenv "DZN_UNINSTALLED") (string-append %prefix "/bin"))
      "/gnu/store/fabyp52qj67piyzm3qbsndys6h3jf525-dezyne-mingw-2.16.2/bin"))

(define %template-dir
  (string-append %pkgdatadir "/dzn/templates"))

(define %test-dir
  (string-append %pkgdatadir "/test"))

(define %guilemoduledir
  "/gnu/store/fabyp52qj67piyzm3qbsndys6h3jf525-dezyne-mingw-2.16.2/share/guile/site/3.0")

(define %guileobjectdir
  "/gnu/store/fabyp52qj67piyzm3qbsndys6h3jf525-dezyne-mingw-2.16.2/lib/guile/3.0/site-ccache")

(define %package-name
  "Dezyne")

(define %package-version
  "2.16.2")

(define %version-major
  2)

(define %version-minor
  16)

(define %version-patch
  2)

(define %dzn
  (if (mingw?) "dzn.cmd"
      (string-append %bindir "/dzn")))

(define %default-languages
  (string-split (string-trim-both "c++") #\space))

(define %copyright-info
  "Copyright (C) 2014-2022 the Dezyne authors
")

(define %license-info
  "License AGPLv3+: GNU AGPL version 3 or later <https://gnu.org/licenses/agpl.html>
This is free software: you are free to change and redistribute it.
There is NO WARRANTY, to the extent permitted by law.
")

(define %feature-alist
  '(("async" . ("c++" "cs" "scheme"))
    ("block" . ("c++" "cs" "scheme"))
    ("calling_context" . ("c++" "cs" "scheme"))
    ("collateral" . ("c++" "cs" "scheme"))
    ("defer" . ("c++" "cs" "scheme"))
    ("flush" . ("c++" "cs" "scheme"))
    ("inject" . ("c++" "cs" "javacsript" "scheme"))
    ("space" . ("c" "c++" "cs" "javascript" "scheme"))))
